[pypy-commit] buildbot default: change tannit -> benchmarker

mattip pypy.commits at gmail.com
Thu Apr 18 03:27:17 EDT 2019


Author: Matti Picus <matti.picus at gmail.com>
Branch: 
Changeset: r1079:2e976793596a
Date: 2019-04-18 10:26 +0300
http://bitbucket.org/pypy/buildbot/changeset/2e976793596a/

Log:	change tannit -> benchmarker

diff --git a/bot2/pypybuildbot/master.py b/bot2/pypybuildbot/master.py
--- a/bot2/pypybuildbot/master.py
+++ b/bot2/pypybuildbot/master.py
@@ -66,7 +66,7 @@
 # all ARM buildbot configuration is in arm_master.py
 ARM = load('pypybuildbot.arm_master')
 
-TannitCPU = pypybuilds.TannitCPU
+BenchmarkerLock = pypybuilds.BenchmarkerLock
 WinSlaveLock = pypybuilds.WinSlaveLock
 #SpeedOldLock = pypybuilds.SpeedOldLock
 Bencher4Lock = pypybuilds.Bencher4Lock
@@ -174,9 +174,9 @@
     pypyjit=True,
     app_tests=True)
 
-pypyJITBenchmarkFactory_tannit = pypybuilds.JITBenchmark(host='tannit')
-pypyJITBenchmarkFactory64_tannit = pypybuilds.JITBenchmark(platform='linux64',
-                                                           host='tannit',
+pypyJITBenchmarkFactory = pypybuilds.JITBenchmark(host='benchmarker')
+pypyJITBenchmarkFactory64 = pypybuilds.JITBenchmark(platform='linux64',
+                                                           host='benchmarker',
                                                            postfix='-64')
 pypyJITBenchmarkFactory64_speed = pypybuilds.JITBenchmarkSingleRun(
     platform='linux64',
@@ -286,7 +286,8 @@
 
     'schedulers': [
         # the benchmarks run on benchmarker and (planned) speed-old.python.org.
-        # All the other linux tests run on bencher4.soft-dev.org.
+        # 64 bit linux tests run on bencher4.soft-dev.org.
+        # 32 bit linux tests run on benchmarker.
         Nightly("nightly-0-00", [
             # linux tests
             LINUX32OWN,                # on benchmarker4_32, uses all cores
@@ -322,7 +323,7 @@
         ),
 
         Nightly("nightly-1-00", [
-            #JITBENCH64,                # on tannit64, uses 1 core (in part exclusively)
+            #JITBENCH64,                # on benchmarker, uses 1 core (in part exclusively)
             #JITBENCH64_NEW,            # on speed64, uses 1 core (in part exclusively)
 
             ], branch=None, hour=5, minute=0,
@@ -331,7 +332,7 @@
         ),
 
         Triggerable("NUMPY64_scheduler", [
-            #NUMPY_64,                  # on tannit64, uses 1 core, takes about 5min.
+            #NUMPY_64,                  # uses 1 core, takes about 5min.
         ]),
 
         Triggerable("NUMPYWIN_scheduler", [
@@ -413,14 +414,14 @@
                    "builddir": LINUX32OWN,
                    "factory": pypyOwnTestFactory,
                    "category": 'linux32',
-                   "locks": [TannitCPU.access('counting')],
+                   "locks": [BenchmarkerLock.access('counting')],
                   },
                   {"name": LINUX32RPYTHON,
                    "slavenames": ["salsa_32", "benchmarker32"],
                    "builddir": LINUX32RPYTHON,
                    "factory": pypyRPythonTestFactory,
                    "category": 'linux32',
-                   "locks": [TannitCPU.access('counting')],
+                   "locks": [BenchmarkerLock.access('counting')],
                   },
                   {"name": LINUX64OWN,
                    #"slavenames": ["bencher4", "speed-old"],
@@ -444,7 +445,7 @@
                    "builddir": APPLVLLINUX32,
                    "factory": pypyTranslatedAppLevelTestFactory,
                    'category': 'linux32',
-                   "locks": [TannitCPU.access('counting')],
+                   "locks": [BenchmarkerLock.access('counting')],
                   },
                   {"name": APPLVLLINUX64,
                    #"slavenames": ["bencher4", "speed-old"],
@@ -460,7 +461,7 @@
                    "builddir": LIBPYTHON_LINUX32,
                    "factory": pypyTranslatedLibPythonTestFactory,
                    'category': 'linux32',
-                   "locks": [TannitCPU.access('counting')],
+                   "locks": [BenchmarkerLock.access('counting')],
                   },
                   {"name": LIBPYTHON_LINUX64,
                    #"slavenames": ["bencher4", "speed-old"],
@@ -476,7 +477,7 @@
                    'builddir' : JITLINUX32,
                    'factory' : pypyJITTranslatedTestFactory,
                    'category' : 'linux32',
-                   "locks": [TannitCPU.access('counting')],
+                   "locks": [BenchmarkerLock.access('counting')],
                    },
                   {'name': JITLINUX64,
                    #'slavenames': ["bencher4", "speed-old"],
@@ -487,9 +488,9 @@
                    "locks": [Bencher4Lock.access('counting')],
                   },
                   {"name": JITBENCH64,
-                   "slavenames": ["tannit64", "benchmarker"],
+                   "slavenames": ["benchmarker"],
                    "builddir": JITBENCH64,
-                   "factory": pypyJITBenchmarkFactory64_tannit,
+                   "factory": pypyJITBenchmarkFactory64,
                    "category": "benchmark-run",
                    # the locks are acquired with fine grain inside the build
                    },
@@ -564,7 +565,7 @@
                    'builddir': NUMPY_64,
                    'factory': pypyNumpyCompatability,
                    'category': 'numpy',
-                   #'locks': [TannitCPU.access('counting')],
+                   'locks': [BenchmarkerLock.access('counting')],
                    "locks": [Bencher4Lock.access('counting')],
                   },
                   {'name': NUMPY_WIN,


More information about the pypy-commit mailing list
diff --git a/bot2/pypybuildbot/builds.py b/bot2/pypybuildbot/builds.py
--- a/bot2/pypybuildbot/builds.py
+++ b/bot2/pypybuildbot/builds.py
@@ -15,15 +15,15 @@
 # to be run on each slave in parallel.  However, they assume that each
 # buildslave is on a differen physical machine, which is not the case for
 # bencher4 and bencher4_32.  As a result, we have to use a global lock, and
 # manually tell each builder that uses tannit to acquire it.
 #
 # Look at the various "locks" session in master.py/BuildmasterConfig.  For
 # benchmarks, the locks is aquired for the single steps: this way we can run
 # translations in parallel, but then the actual benchmarks are run in
 # sequence.
 
-# tannit has 8 logical CPUs, but only 4 physical ones, and memory for ~3 translations
-TannitCPU = locks.MasterLock('tannit_cpu', maxCount=3)
+# benchmarker has 8 logical CPUs, but only 4 physical ones, and memory for ~6 translations
+BenchmarkerLock = locks.MasterLock('benchmarker', maxCount=3)
 SpeedPythonCPU = locks.MasterLock('speed_python_cpu', maxCount=24)
 WinSlaveLock = locks.SlaveLock('win_cpu', maxCount=1)
 # speed-old has 24 cores, but memory for ~2 translations
@@ -809,7 +809,7 @@
             self.addStep(Trigger(schedulerNames=[trigger]))
 
 class JITBenchmarkSingleRun(factory.BuildFactory):
-    def __init__(self, platform='linux', host='tannit', postfix=''):
+    def __init__(self, platform='linux', host='speed_python', postfix=''):
         factory.BuildFactory.__init__(self)
 
         repourl = 'https://bitbucket.org/pypy/benchmarks'
@@ -817,8 +817,8 @@
                   force_branch='single-run')
         #
         setup_steps(platform, self)
-        if host == 'tannit':
-            lock = TannitCPU
+        if host == 'benchmarker':
+            lock = BenchmarkerLock
         elif host == 'speed_python':
             lock = SpeedPythonCPU
         else:
@@ -854,7 +854,7 @@
                                          workdir="."))
 
 class JITBenchmark(factory.BuildFactory):
-    def __init__(self, platform='linux', host='tannit', postfix=''):
+    def __init__(self, platform='linux', host='benchmarker', postfix=''):
         factory.BuildFactory.__init__(self)
 
         #
@@ -862,8 +862,8 @@
         update_hg(platform, self, repourl, 'benchmarks', use_branch=False)
         #
         setup_steps(platform, self)
-        if host == 'tannit':
-            lock = TannitCPU
+        if host == 'benchmarker':
+            lock = BenchmarkerLock
         elif host == 'speed_python':
             lock = SpeedPythonCPU
         else:
@@ -15,15 +15,15 @@
 # buildslave is on a differen physical machine, which is not the case for
 # bencher4 and bencher4_32.  As a result, we have to use a global lock, and
-# manually tell each builder that uses tannit to acquire it.
+# manually tell each builder that uses benchmarker to acquire it.
 #
 # Look at the various "locks" session in master.py/BuildmasterConfig.  For